"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var express_1 = __importDefault(require("express"));
var figlet_1 = __importDefault(require("figlet"));
var errorHanlder_1 = require("../middleware/errorHanlder");
var cors_1 = __importDefault(require("cors"));
var auth_1 = __importDefault(require("../middleware/auth"));
var env_1 = __importDefault(require("../config/env"));
var routes_1 = __importDefault(require("./routes"));
var morgan_1 = __importDefault(require("../middleware/morgan"));
var app = (0, express_1.default)();
//cors
app.use(function (req, res, next) {
    res.setHeader("Access-Control-Allow-Origin", "*");
    res.setHeader("Access-Control-Allow-Methods", "GET, POST, PUT, DELETE");
    res.setHeader("Access-Control-Allow-Headers", "Content-Type");
    res.setHeader("Access-Control-Allow-Credentials", "true");
    res.setHeader('Cache-Control', 'no-cache, no-store, must-revalidate');
    res.setHeader('Pragma', 'no-cache');
    res.setHeader('Expires', 'Fri 05 Jan 2090 00:00:00 GMT');
    next();
});
app.use((0, cors_1.default)({ origin: "*" }));
app.use(express_1.default.json());
// authentication
app.use(auth_1.default);
// static routes
app.use(routes_1.default._public);
//logger
app.use(morgan_1.default);
app.use("/user/auth", routes_1.default.auth);
app.use("/user/project", routes_1.default.project);
app.use("/user/wallet", routes_1.default.wallet);
app.use("/user/upload", routes_1.default.upload);
app.use(errorHanlder_1.errorHandler);
app.listen(env_1.default.port, function () {
    figlet_1.default.text(" ", {
        font: "Big",
    }, function (err, data) {
        if (err) {
            console.log("Something went wrong...");
            console.dir(err);
            return;
        }
        console.log(data);
        console.log("Listening \uD83E\uDD19 On PORT ".concat(env_1.default.port, " \uD83D\uDE80"));
    });
});
